from model.modelo import Modelo
import ctrl.utiles as utilesCtrl
import os, errno
import bd.comunesBD as comunesBD
import logging

class GestorWorkingDir:
	"""El directorio de trabajo contiene tres directorios:
		* /modelos
		* /snaps
		* /entornos
		En utilesCtrl del paquete 'ctrl' puede verse su ubicacion.
	"""
	def __init__(self):
		self.workdir = self.getWorkingdir()
		
		if self.workdir is not None:
			self.entornosDir = self.workdir + utilesCtrl.ENTORNO_DIR
			self.snapsDir = self.workdir + utilesCtrl.SNAP_DIR
			self.modelosDir = self.workdir + utilesCtrl.MODELO_DIR

	def generaConfig(self, modelo):
		# Crea el fichero de configuracion para el modelo.
		# Este fichero contiene los parametros necesarios para los scripts de creacion de imagenes.
		
		fichModelo = self.modelosDir + '/%s/%s.conf' % (modelo.nombre, modelo.nombre)
		
		lineas = [  '%s=\"%s\"\n' % (utilesCtrl.sc_arquitectura, modelo.arquitectura),
				'%s=\"%s\"\n' % (utilesCtrl.sc_instalacion, modelo.instalacion),
				'%s=\"%s\"\n' % (utilesCtrl.sc_desktop, modelo.entornoGrafico),
				'%s=\"%s\"\n' % (utilesCtrl.sc_hostname, modelo.hostname),
				'%s=\"%s\"\n' % (utilesCtrl.sc_username, modelo.username) ]

		# Si el directorio para el modelo no fue creado, se crea.
		dir = os.path.dirname(fichModelo)
		try:	
			os.stat(dir)
		except OSError:
			os.makedirs(dir)

		with open(fichModelo, 'w') as f:
			for linea in lineas:
				f.write(linea)

	def estableceWorkdir(self, path, pagina):

		self.workdir = path
		try:	
			os.stat(self.workdir)
		except OSError:
			os.makedirs(self.workdir)
	
		dirModelo = self.workdir + utilesCtrl.MODELO_DIR
		dirSnap  = self.workdir + utilesCtrl.SNAP_DIR
		dirEntorno = self.workdir + utilesCtrl.ENTORNO_DIR
		
		if not os.path.exists(dirModelo):
			os.makedirs(dirModelo)	
		if not os.path.exists(dirSnap):
			os.makedirs(dirSnap)
		if not os.path.exists(dirEntorno):
			os.makedirs(dirEntorno)

		# Se crea el nuevo fichero de logging en el workdir.
		self.iniciaLogger()
		
		comunesBD.updateWorkdir(path, utilesCtrl.version)
		pagina.showTabs()
		
	def getWorkingdir(self):
		configuracion = comunesBD.obtenWorkingdir(utilesCtrl.version)

		return configuracion["workdir"]
		
	def iniciaLogger(self):
		logfile = self.workdir + ('/%s') % (utilesCtrl.LOG_FILE)
		print logfile
		logging.basicConfig(filename=logfile, level=logging.INFO)		
		

